<p align="center" style="font-size:40px; margin:0px 10px 0px 10px">
    <em>[Py]S-ESD</em>
</p>
<p align="center">
    <em>Seasonal Extreme Studentized Deviate(S-ESD) in Python.
</em>
</p>

# About
Seasonal Extreme Studentized Deviate(S-ESD) in Python.

# Installation

Get latest version from PyPI:

```shell
pip install pysesd
```

# Examples

## Simple example

![](./figures/simple.png)

## Twitter example

![](./figures/twitter.png)


# References
- [twitter/AnomalyDetection](https://github.com/twitter/AnomalyDetection)